/*
 * buzzer.c
 *
 *  Created on: 21.11.2010
 *      Author: Filip
 */
#include "buzzer.h"

void buzzer_initialize(){
	volatile avr32_tc_t *tc = TC;
	  tc_waveform_opt_t buzzer_opt =
	  	    {
	  	      .channel  = TC_1_CHANNEL_ID,        // Channel selection.

	  	      .bswtrg   = TC_EVT_EFFECT_NOOP,           // Software trigger effect on TIOB.
	  	      .beevt    = TC_EVT_EFFECT_NOOP,           // External event effect on TIOB.
	  	      .bcpc     = TC_EVT_EFFECT_NOOP,           // RC compare effect on TIOB.
	  	      .bcpb     = TC_EVT_EFFECT_NOOP,           // RB compare effect on TIOB.

	  	      .aswtrg   = TC_EVT_EFFECT_NOOP,           // Software trigger effect on TIOA.
	  	      .aeevt    = TC_EVT_EFFECT_NOOP,           // External event effect on TIOA.
	  	      .acpc     = TC_EVT_EFFECT_TOGGLE,         // RC compare effect on TIOA: toggle.
	  	      .acpa     = TC_EVT_EFFECT_TOGGLE,         // RA compare effect on TIOA: toggle (other possibilities are none, set and clear).

	  	      .wavsel   = TC_WAVEFORM_SEL_UP_MODE_RC_TRIGGER,
	  	      .enetrg   = FALSE,                        // External event trigger enable.
	  	      .eevt     = TC_EXT_EVENT_SEL_TIOB_INPUT,  // External event selection.
	  	      .eevtedg  = TC_SEL_NO_EDGE,               // External event edge selection.
	  	      .cpcdis   = FALSE,                        // Counter disable when RC compare.
	  	      .cpcstop  = FALSE,                        // Counter clock stopped with RC compare.

	  	      .burst    = TC_BURST_NOT_GATED,           // Burst signal selection.
	  	      .clki     = TC_CLOCK_RISING_EDGE,         // Clock inversion.
	  	      .tcclks   = TC_CLOCK_SOURCE_TC4
	  	    };

	  	  gpio_enable_module_pin(TC_1_CHANNEL_PIN, TC_1_CHANNEL_FUNCTION);

	  	    // Initialize the timer/counter.
	  	  tc_init_waveform(tc, &buzzer_opt);  // Initialize the timer/counter waveform.
	  	    // Set the compare triggers.
	  	  tc_write_ra(tc, TC_1_CHANNEL_ID, 500);     // Set RA value.
	  	  tc_write_rc(tc, TC_1_CHANNEL_ID, 500);     // Set RC value.
	  	    // Start the timer/counter.
//	  	  tc_start(tc, TC_1_CHANNEL_ID);

}

void buzzer_on(int frequency){
	volatile avr32_tc_t *tc = TC;
	tc_write_ra(tc, TC_1_CHANNEL_ID, frequency);
	tc_write_rc(tc, TC_1_CHANNEL_ID, frequency);
	tc_start(tc, TC_1_CHANNEL_ID);
}

void buzzer_off(){
	volatile avr32_tc_t *tc = TC;
	tc_stop(tc, TC_1_CHANNEL_ID);
}

void buzzer_set(int frequency){
	volatile avr32_tc_t *tc = TC;
	tc_write_ra(tc, TC_1_CHANNEL_ID, frequency);
	tc_write_rc(tc, TC_1_CHANNEL_ID, frequency);
}
